@@ -1697,14 +1697,14 @@ wstdcall void *WIN_FUNC(MmAllocateContiguousMemorySpecifyCache,5)
 #ifdef CONFIG_X86_64
 	/* GFP_DMA is really only 16MB even on x86-64, but there is no
 	 * other zone available */
-	if (highest <= DMA_31BIT_MASK)
+	if (highest <= DMA_BIT_MASK(31))
 		flags |= __GFP_DMA;
-	else if (highest <= DMA_32BIT_MASK)
+	else if (highest <= DMA_BIT_MASK(32))
 		flags |= __GFP_DMA32;
 #else
-	if (highest <= DMA_24BIT_MASK)
+	if (highest <= DMA_BIT_MASK(24))
 		flags |= __GFP_DMA;
-	else if (highest > DMA_30BIT_MASK)
+	else if (highest > DMA_BIT_MASK(30))
 		flags |= __GFP_HIGHMEM;
 #endif
 	addr = wrap_get_free_pages(flags, size);
@@ -1759,8 +1759,8 @@ wstdcall void WIN_FUNC(MmUnmapIoSpace,2)
 wstdcall ULONG WIN_FUNC(MmSizeOfMdl,2)
 	(void *base, ULONG length)
 {
-	return (sizeof(struct mdl) +
-		(sizeof(PFN_NUMBER) * SPAN_PAGES(base, length)));
+	return sizeof(struct mdl) +
+	       (sizeof(PFN_NUMBER) * SPAN_PAGES(base, length));
 }
 
 struct mdl *allocate_init_mdl(void *virt, ULONG length)
@@ -2388,7 +2388,7 @@ noregparm ULONG WIN_FUNC(DbgPrint,12)
 
 	va_start(args, format);
 	vsnprintf(buf, sizeof(buf), format, args);
-	printk(KERN_DEBUG "%s (%s): %s", DRIVER_NAME, __FUNCTION__, buf);
+	printk(KERN_DEBUG "%s (%s): %s", DRIVER_NAME, __func__, buf);
 	va_end(args);
 #endif
 	return STATUS_SUCCESS;
